@@ -11,7 +11,7 @@ from discord.app_commands import Choice, Transformer
 from discord.ext import commands
 from rapidfuzz import fuzz
 
-from pylav import getLogger
+from pylav._logging import getLogger
 from pylav.types import ContextT, InteractionT
 from pylav.utils import shorten_string
 
@@ -40,7 +40,7 @@ else:
         @classmethod
         async def convert(cls, ctx: ContextT, arg: str) -> list[Station]:
             """Converts a station name to a matching object"""
-            from pylav import EntryNotFoundError
+            from pylav.exceptions import EntryNotFoundError
 
             try:
                 station = await ctx.lavalink.radio_browser.station_by_uuid(arg)
@@ -121,6 +121,7 @@ else:
                 return await asyncio.to_thread(fuzz.token_set_ratio, current, c.name)
 
             extracted: list[Station] = await heapq.nlargest(asyncstdlib.iter(stations), n=25, key=_filter)
+
             return [
                 Choice(
                     name=shorten_string(e.name, max_length=100) if e.name else _("Unnamed"), value=f"{e.stationuuid}"
@@ -132,7 +133,7 @@ else:
         @classmethod
         async def convert(cls, ctx: ContextT, arg: str) -> list[Tag]:
             """Converts a Tag name to to a matching object"""
-            from pylav import EntryNotFoundError
+            from pylav.exceptions import EntryNotFoundError
 
             try:
                 tags = await ctx.lavalink.radio_browser.tags()
@@ -162,6 +163,7 @@ else:
                 return await asyncio.to_thread(fuzz.token_set_ratio, current, c.name)
 
             extracted = await heapq.nlargest(asyncstdlib.iter(tags), n=25, key=_filter)
+
             return [
                 Choice(name=shorten_string(e.name, max_length=100) if e.name else _("Unnamed"), value=f"{e.name}")
                 for e in extracted
@@ -171,7 +173,7 @@ else:
         @classmethod
         async def convert(cls, ctx: ContextT, arg: str) -> list[Language]:
             """Converts a Language name to to a matching object"""
-            from pylav import EntryNotFoundError
+            from pylav.exceptions import EntryNotFoundError
 
             try:
                 langs = await ctx.lavalink.radio_browser.languages()
@@ -201,6 +203,7 @@ else:
                 return await asyncio.to_thread(fuzz.token_set_ratio, current, c.name)
 
             extracted = await heapq.nlargest(asyncstdlib.iter(languages), n=25, key=_filter)
+
             return [
                 Choice(name=shorten_string(e.name, max_length=100) if e.name else _("Unnamed"), value=f"{e.name}")
                 for e in extracted
@@ -210,7 +213,7 @@ else:
         @classmethod
         async def convert(cls, ctx: ContextT, arg: str) -> list[State]:
             """Converts a State name to to a matching object"""
-            from pylav import EntryNotFoundError
+            from pylav.exceptions import EntryNotFoundError
 
             try:
                 states = await ctx.lavalink.radio_browser.states()
@@ -248,6 +251,7 @@ else:
                 return await asyncio.to_thread(fuzz.token_set_ratio, current, c.name)
 
             extracted = await heapq.nlargest(asyncstdlib.iter(states), n=25, key=_filter)
+
             return [
                 Choice(name=shorten_string(e.name, max_length=100) if e.name else _("Unnamed"), value=f"{e.name}")
                 for e in extracted
@@ -257,7 +261,7 @@ else:
         @classmethod
         async def convert(cls, ctx: ContextT, arg: str) -> list[Codec]:
             """Converts a Codec name to to a matching object"""
-            from pylav import EntryNotFoundError
+            from pylav.exceptions import EntryNotFoundError
 
             try:
                 codecs = await ctx.lavalink.radio_browser.codecs()
@@ -287,6 +291,7 @@ else:
                 return await asyncio.to_thread(fuzz.token_set_ratio, current, c.name)
 
             extracted = await heapq.nlargest(asyncstdlib.iter(codecs), n=25, key=_filter)
+
             return [
                 Choice(name=shorten_string(e.name, max_length=100) if e.name else _("Unnamed"), value=f"{e.name}")
                 for e in extracted
@@ -296,7 +301,7 @@ else:
         @classmethod
         async def convert(cls, ctx: ContextT, arg: str) -> list[CountryCode]:
             """Converts a CountryCode name to to a matching object"""
-            from pylav import EntryNotFoundError
+            from pylav.exceptions import EntryNotFoundError
 
             try:
                 countrycodes = await ctx.lavalink.radio_browser.countrycodes()
@@ -327,6 +332,7 @@ else:
                 return await asyncio.to_thread(fuzz.token_set_ratio, current, c.name)
 
             extracted = await heapq.nlargest(asyncstdlib.iter(countrycodes), n=25, key=_filter)
+
             return [
                 Choice(name=shorten_string(e.name, max_length=100) if e.name else _("Unnamed"), value=f"{e.name}")
                 for e in extracted
@@ -336,7 +342,7 @@ else:
         @classmethod
         async def convert(cls, ctx: ContextT, arg: str) -> list[Country]:
             """Converts a Country name to to a matching object"""
-            from pylav import EntryNotFoundError
+            from pylav.exceptions import EntryNotFoundError
 
             try:
                 countries = await ctx.lavalink.radio_browser.countries()
@@ -373,6 +379,7 @@ else:
                 return await asyncio.to_thread(fuzz.token_set_ratio, current, c.name)
 
             extracted = await heapq.nlargest(asyncstdlib.iter(countries), n=25, key=_filter)
+
             return [
                 Choice(name=shorten_string(e.name, max_length=100) if e.name else _("Unnamed"), value=f"{e.name}")
                 for e in extracted
